@@ -4,6 +4,7 @@ from .server_utils import parse_variant
 
 from flask import url_for
 
+import urllib.parse
 import itertools
 import re
 import copy
@@ -20,14 +21,18 @@ from typing import List,Dict,Any,Optional,Iterator
 #         - but, stringy things should just be in a streamtable anyways.
 
 
+def get_sqlite3_readonly_connection(filepath:str):
+    # `check_same_thread=False` lets WSGI work. Readonly makes me feel better about disabling `check_same_thread`.
+    return sqlite3.connect('file:{}?mode=ro'.format(urllib.parse.quote(filepath)), uri=True, check_same_thread=False)
+
 class Autocompleter(object):
     def __init__(self, phenos:Dict[str,Dict[str,Any]]):
         self._phenos = copy.deepcopy(phenos)
         self._preprocess_phenos()
 
-        self._cpras_rsids_sqlite3 = sqlite3.connect(get_filepath('cpras-rsids-sqlite3'))
+        self._cpras_rsids_sqlite3 = get_sqlite3_readonly_connection(get_filepath('cpras-rsids-sqlite3'))
         self._cpras_rsids_sqlite3.row_factory = sqlite3.Row
-        self._gene_aliases_sqlite3 = sqlite3.connect(get_filepath('gene-aliases-sqlite3'))
+        self._gene_aliases_sqlite3 = get_sqlite3_readonly_connection(get_filepath('gene-aliases-sqlite3'))
         self._gene_aliases_sqlite3.row_factory = sqlite3.Row
 
         self._autocompleters = [
@@ -100,22 +105,20 @@ class Autocompleter(object):
                     }
 
     def _autocomplete_rsid(self, query:str) -> Iterator[Dict[str,str]]:
-        query = query.lower()
+        key = query.lower()
         if query.startswith('rs'):
-            key = query
-
-            rsid_cpra_pairs = list(self._cpras_rsids_sqlite3.execute(
-                'SELECT cpra,rsid FROM cpras_rsids WHERE rsid LIKE ? ORDER BY LENGTH(rsid),rsid LIMIT 100',
-                (key+'%',)
-            ))
-            for row in rsid_cpra_pairs:
-                rsid, cpra = row['rsid'], row['cpra']
-                cpra_display = cpra.replace('-', ':', 1)
-                yield {
-                    "value": cpra_display,
-                    "display": '{} ({})'.format(rsid, cpra_display),
-                    'url': url_for('.variant_page', query=cpra_display),
-                }
+            ## <https://sqlite.org/np1queryprob.html> recommends doing lots of small queries, and it's fast:
+            for suffix_length in [0,1,2]:
+                for suffix in (''.join(digits) for digits in itertools.product('0123456789', repeat=suffix_length)):
+                    rows = list(self._cpras_rsids_sqlite3.execute('SELECT cpra,rsid FROM cpras_rsids WHERE rsid=?', (key+suffix,)))
+                    for row in rows:
+                        rsid, cpra = row['rsid'], row['cpra']
+                        cpra_display = cpra.replace('-', ':', 1)
+                        yield {
+                            "value": cpra_display,
+                            "display": '{} ({})'.format(rsid, cpra_display),
+                            'url': url_for('.variant_page', query=cpra_display),
+                        }
 
     def _autocomplete_phenocode(self, query:str) -> Iterator[Dict[str,str]]:
         query = self._process_string(query)
