@@ -4,13 +4,13 @@ from ..utils import get_phenolist, get_gene_tuples, pad_gene, PheWebError, vep_c
 from .. import conf
 from .. import parse_utils
 from ..file_utils import get_filepath, get_pheno_filepath, VariantFileReader
-from .server_utils import get_variant, get_random_page, get_pheno_region
+from .server_utils import get_variant, get_random_page, get_pheno_region, relative_redirect
 from .autocomplete import Autocompleter
 from .auth import GoogleSignIn
 from ..version import version as pheweb_version
 from ..import weetabix
 
-from flask import Flask, jsonify, render_template, request, redirect, abort, flash, send_from_directory, send_file, session, url_for, Blueprint
+from flask import Flask, jsonify, render_template, request, abort, flash, send_from_directory, send_file, session, url_for, Blueprint
 from flask_compress import Compress
 from flask_login import LoginManager, UserMixin, login_user, logout_user, current_user
 
@@ -39,7 +39,6 @@ app.config['HG_BUILD_NUMBER'] = conf.get_hg_build_number()
 app.config['GRCH_BUILD_NUMBER'] = conf.get_grch_build_number()
 app.config['PHEWEB_VERSION'] = pheweb_version
 app.config['LZJS_VERSION'] = conf.get_lzjs_version()
-app.config['LZJS_VERSION_PHEWAS'] = conf.get_lzjs_version_phewas()
 app.config['URLPREFIX'] = conf.get_urlprefix()
 app.config['USE_WHITELIST'] = conf.is_login_required() and bool(conf.get_login_allowlist())
 if conf.get_custom_templates_dir():
@@ -64,7 +63,7 @@ def check_auth(func):
         if current_user.is_anonymous:
             print('unauthorized user visited {!r}'.format(request.path))
             session['original_destination'] = request.path
-            return redirect(url_for('.get_authorized'))
+            return relative_redirect(url_for('.get_authorized'))
         print('{} visited {!r}'.format(current_user.email, request.path))
         if conf.get_login_allowlist():
             assert current_user.email.lower() in conf.get_login_allowlist(), current_user
@@ -90,7 +89,7 @@ def go():
         die("How did you manage to get a null query?")
     best_suggestion = autocompleter.get_best_completion(query)
     if best_suggestion:
-        return redirect(best_suggestion['url'])
+        return relative_redirect(best_suggestion['url'])
     die("Couldn't find page for {!r}".format(query))
 
 @bp.route('/api/variant/<query>')
@@ -124,18 +123,26 @@ def api_pheno(phenocode:str):
 @bp.route('/api/manhattan-filtered/pheno/<phenocode>.json')
 @check_auth
 def api_pheno_filtered(phenocode):
-    pheno = phenos[phenocode]
+    # Parse parameters from URL
+    try: pheno = phenos[phenocode]
+    except KeyError: abort(404, description="That phenocode wasn't found for this dataset.")
     indel = request.args.get('indel', '')
-    # TODO: replace these exceptions with abort(404)
-    if indel: assert indel in ['true', 'false'], indel
+    if indel not in ['', 'true', 'false']: abort(404, description="Invalid value for GET parameter `indel=`.  Valid values are ['', 'true', 'false'].")
     consequence_category = request.args.get('csq', '')
-    if consequence_category: assert consequence_category in ['lof', 'nonsyn'], consequence_category
-    min_maf = float(request.args['min_maf']) if request.args.get('min_maf','') else None
-    max_maf = float(request.args['max_maf']) if request.args.get('max_maf','') else None
+    if consequence_category not in ['', 'lof', 'nonsyn']: abort(404, description="Invalid value for GET parameter `csq=`.  Valid values are ['', 'lof', 'nonsyn'].")
+    min_maf, max_maf = None, None
+    if request.args.get('min_maf'):
+        try: min_maf = float(request.args['min_maf'])
+        except Exception: abort(404, description="Failed to parse GET parameter `min_maf=`.")
+    if request.args.get('max_maf'):
+        try: max_maf = float(request.args['max_maf'])
+        except Exception: abort(404, description="Failed to parse GET parameter `max_maf=`.")
+    # Get variants according to filter
     chosen_variants = []  # TODO: stream straight from VariantFileReader() -> Binner() without this intermediate list
     weakest_pval_seen = 0
     num_variants = 0
-    filepath = get_pheno_filepath('best_of_pheno', phenocode)
+    try: filepath = get_pheno_filepath('best_of_pheno', phenocode)
+    except Exception: abort(404, description="Failed to find a best_of_pheno file.  Perhaps `pheweb best-of-pheno` wasn't run.")
     with VariantFileReader(filepath) as vfr:
         for v in vfr:
             num_variants += 1
@@ -199,7 +206,7 @@ def random_page():
     url = get_random_page()
     if url is None:
         die("Sorry, it looks like no hits in this pheweb reached the significance threshold.")
-    return redirect(url)
+    return relative_redirect(url)
 
 @bp.route('/pheno/<phenocode>')
 @check_auth
@@ -409,9 +416,9 @@ def about_page():
 
 def die(message='no message', exception=None):
     if exception is not None:
-        print(exception)
+        print('Exception:', exception)
         traceback.print_exc()
-    print(message)
+    print(message, flush=True)
     flash(message)
     abort(404)
 
@@ -459,13 +466,13 @@ if conf.is_login_required():
     def logout():
         print(current_user.email, 'logged out')
         logout_user()
-        return redirect(url_for('.homepage'))
+        return relative_redirect(url_for('.homepage'))
 
     @bp.route('/login_with_google')
     def login_with_google():
         "this route is for the login button"
         session['original_destination'] = url_for('.homepage')
-        return redirect(url_for('.get_authorized'))
+        return relative_redirect(url_for('.get_authorized'))
 
     @bp.route('/get_authorized')
     def get_authorized():
@@ -478,12 +485,12 @@ if conf.is_login_required():
                 del session['original_destination'] # We don't want old destinations hanging around.  If this leads to problems with re-opening windows, disable this line.
             else:
                 orig_dest = url_for('.homepage')
-            return redirect(orig_dest)
+            return relative_redirect(orig_dest)
 
     @bp.route('/callback/google')
     def oauth_callback_google():
         if not current_user.is_anonymous:
-            return redirect(url_for('.homepage'))
+            return relative_redirect(url_for('.homepage'))
         try:
             username, email = google_sign_in.callback() # oauth.callback reads request.args.
         except Exception as exc:
@@ -491,21 +498,21 @@ if conf.is_login_required():
             print(exc)
             print(traceback.format_exc())
             flash('Something is wrong with authentication.  Please email pjvh@umich.edu')
-            return redirect(url_for('.homepage'))
+            return relative_redirect(url_for('.homepage'))
         if email is None:
             # I need a valid email address for my user identification
             flash('Authentication failed by failing to get an email address.  Please email pjvh@umich.edu')
-            return redirect(url_for('.homepage'))
+            return relative_redirect(url_for('.homepage'))
 
         if conf.get_login_allowlist() and email.lower() not in conf.get_login_allowlist():
             flash('Your email, {!r}, is not in the list of allowed emails.'.format(email))
-            return redirect(url_for('.homepage'))
+            return relative_redirect(url_for('.homepage'))
 
         # Log in the user, by default remembering them for their next visit.
         user = User(username, email)
         login_user(user, remember=True)
 
         print(user.email, 'logged in')
-        return redirect(url_for('.get_authorized'))
+        return relative_redirect(url_for('.get_authorized'))
 
 app.register_blueprint(bp, url_prefix = app.config['URLPREFIX'])
