@@ -24,7 +24,7 @@ function custom_LocusZoom_Layouts_get(layout_type, layout_name, customizations)
     return layout;
 }
 
-LocusZoom.TransformationFunctions.set("percent", function(x) {
+LocusZoom.TransformationFunctions.add("percent", function(x) {
     if (x === 1) { return "100%"; }
     x = (x * 100).toPrecision(2);
     if (x.indexOf('.') !== -1) { x = x.replace(/0+$/, ''); }
@@ -81,7 +81,8 @@ LocusZoom.ScaleFunctions.add("effect_direction", function(parameters, input){
         return category_order[d.category];
     });
     window.unique_categories = d3.set(window.variant.phenos.map(_.property('category'))).values();
-    window.color_by_category = ((unique_categories.length>10) ? d3.scale.category20() : d3.scale.category10())
+    const category20 = d3.schemeCategory10.concat(d3.schemeCategory10);  /* d3 removed category20, so I make this terrible version */
+    window.color_by_category = d3.scaleOrdinal((unique_categories.length > 10) ? category20 : d3.schemeCategory10)
         .domain(unique_categories);
 
     window.variant.phenos.forEach(function(d, i) {
@@ -101,29 +102,33 @@ LocusZoom.ScaleFunctions.add("effect_direction", function(parameters, input){
         if (x === 0) return best_neglog10_pval * 1.1;
         return -Math.log(x) / Math.LN10;
     };
-    LocusZoom.TransformationFunctions.set("neglog10_handle0", neglog10_handle0);
+    LocusZoom.TransformationFunctions.add("neglog10_handle0", neglog10_handle0);
 
     // Define data sources object
-    LocusZoom.Data.PheWASSource.prototype.getData = function(state, fields, outnames, trans) {
-        // Override all parsing, namespacing, and field extraction mechanisms, and load data embedded within the page
-        trans = trans || [];
+    // TODO: Can this be replaced with StaticSource + deepcopy?
+    LocusZoom.Adapters.extend('PheWASLZ', 'PheWebSource', {
+        getData: function(state, fields, outnames, trans) {
+            // Override all parsing, namespacing, and field extraction mechanisms, and load data embedded within the page
+            trans = trans || [];
 
-        var data = deepcopy(window.variant.phenos); //otherwise LZ adds attributes I don't want to the original data.
-        data.forEach(function(d, i) {
-            data[i].x = i;
-            data[i].id = i.toString();
-            trans.forEach(function(transformation, t){
-                if (typeof transformation === "function"){
-                    data[i][outnames[t]] = transformation(data[i][fields[t]]);
-                }
+            var data = deepcopy(window.variant.phenos); //otherwise LZ adds attributes I don't want to the original data.
+            data.forEach(function(d, i) {
+                data[i].x = i;
+                data[i].id = i.toString();
+                trans.forEach(function(transformation, t){
+                    if (typeof transformation === "function"){
+                        data[i][outnames[t]] = transformation(data[i][fields[t]]);
+                    }
+                });
             });
-        });
-        return function(chain) {
-            return {header: chain.header || {}, body: data};
-        }.bind(this);
-    };
+            return function(chain) {
+                return {header: chain.header || {}, body: data};
+            }.bind(this);
+        }
+    });
+
     var data_sources = new LocusZoom.DataSources()
-      .add("phewas", ["PheWASLZ", {url: '/this/is/not/used'}]);
+      .add("phewas", ["PheWebSource", {url: '/this/is/not/used'}]);
 
     var neglog10_significance_threshold = -Math.log10(0.05 / window.variant.phenos.length);
 
@@ -132,10 +137,13 @@ LocusZoom.ScaleFunctions.add("effect_direction", function(parameters, input){
             variant: ['chrom', 'pos', 'ref', 'alt'].map(function(d) { return window.variant[d];}).join("-"),
         },
         dashboard: {
-            components: [{type: "download", position: "right"}],
+            components: [
+                {type: "download", position: "right"},
+                {type: "download_png", position: "right"},
+            ],
         },
         min_height: 400,
-        responsive_resize: "width_only",
+        responsive_resize: true,
         mouse_guide: false,
         panels: [custom_LocusZoom_Layouts_get('panel', 'phewas', {
             min_width: 640, // feels reasonable to me
@@ -148,6 +156,7 @@ LocusZoom.ScaleFunctions.add("effect_direction", function(parameters, input){
                 custom_LocusZoom_Layouts_get('data_layer', 'phewas_pvalues', {
                     unnamespaced: true,
                     id_field: 'idx',
+                    type: 'scatter',
                     color: {
                         field: "category_name",
                         scale_function: "categorical_bin",
@@ -160,8 +169,8 @@ LocusZoom.ScaleFunctions.add("effect_direction", function(parameters, input){
                         {
                             scale_function: 'effect_direction',
                             parameters: {
-                                '+': 'triangle-up',
-                                '-': 'triangle-down'
+                                '+': 'triangle',
+                                '-': 'triangledown'
                             }
                         },
                         'circle'
@@ -214,30 +223,43 @@ LocusZoom.ScaleFunctions.add("effect_direction", function(parameters, input){
 })();
 
 
-// Check MAF/AF/AC and render
-(function() {
-    var isnum = function(d) { return typeof d === "number"; };
+// Check MAF/AF/MAC/AC and render
+// If every pheno has AF, show that.  Otherwise, show MAF for the phenos that have it.
+// If every pheno is the same (when rendered with two sigfigs), show the single value.  Otherwise, the range.
+$(function() {
+    function isnum(d) { return typeof d === "number"; }
+    function minor(frac) { return Math.min(frac, 1-frac); }
+    var afs = window.variant.phenos.map(function(v) {
+        if (isnum(v.af)) { return v.af; }
+        else if (isnum(v.ac) && isnum(v.num_samples)) { return v.ac / (2*v.num_samples); }
+        else { return undefined; }
+    }).filter(isnum);
+    if (afs.length == window.variant.phenos.length) {
+        // Every pheno has AF
+        let af_range = d3.extent(afs).map(two_digit_format);
+        if (af_range[0] === af_range[1]) { $('#maf-range').html(fmt('AF: {0}', af_range[0])); }
+        else { $('#maf-range').html(fmt('AF ranges from {0} to {1}', af_range[0], af_range[1])); }
+        return;
+    }
     var mafs = window.variant.phenos.map(function(v) {
         if (isnum(v.maf))  { return v.maf; }
-        else if (isnum(v.af)) { return Math.min(v.af, 1-v.af); }
-        else if (isnum(v.ac) && isnum(v.num_samples)) { var af = v.ac / (2*v.num_samples); return Math.min(af,1-af); }
+        else if (isnum(v.af)) { return minor(v.af); }
+        else if (isnum(v.mac) && isnum(v.num_samples)) { return v.mac / (2*v.num_samples) }
+        else if (isnum(v.ac) && isnum(v.num_samples)) { return minor(v.ac / (2*v.num_samples)); }
         else { return undefined; }
-    });
-    var num_phenos_with_maf = _.filter(mafs, function(d) { return isnum(d) }).length;
-    if (num_phenos_with_maf === mafs.length) {
-        var range = d3.extent(mafs);
-        $(function() {
-            $('#maf-range').html('<p>MAF ranges from ' + two_digit_format(range[0]) + ' to ' + two_digit_format(range[1]) + '</p>');
-            $('#maf-range p').css('margin-bottom', '0');
-        });
-    } else if (num_phenos_with_maf > 0) {
-        var range = d3.extent(mafs);
-        $(function() {
-            $('#maf-range').html('<p>MAF ranges from ' + two_digit_format(range[0]) + ' to ' + two_digit_format(range[1]) + ' for phenotypes where it is defined</p>');
-            $('#maf-range p').css('margin-bottom', '0');
-        });
+    }).filter(isnum);
+    if (mafs.length === window.variant.phenos.length) {
+        // Every pheno has a MAF
+        let maf_range = d3.extent(mafs).map(two_digit_format);
+        if (maf_range[0] === maf_range[1]) { $('#maf-range').html(fmt('MAF: {0}', maf_range[0])); }
+        else { $('#maf-range').html(fmt('MAF ranges from {0} to {1}', maf_range[0], maf_range[1])); }
+    } else if (mafs.length) {
+        // Show the range of MAFs for the phenotypes that have a MAF
+        var maf_range = d3.extent(mafs).map(two_digit_format);
+        if (maf_range[0] === maf_range[1]) { $('#maf-range').html(fmt('MAF: {0} for phenotypes where it is defined', maf_range[0])); }
+        else { $('#maf-range').html(fmt('MAF ranges from {0} to {1} for phenotypes where it is defined', maf_range[0], maf_range[1])); }
     }
-})();
+});
 
 
 // Check Clinvar and render link.
